@@ -88,14 +88,23 @@ setMethodS3("createLink", "default", function(link=".", target, skip=!overwrite,
   if (any(file.exists(links))) {
     if (skip) {
       pathnameL <- Arguments$getReadablePathname(link, mustExist=TRUE)
-
-      pathnameLA <- getAbsolutePath(Sys.readlink2(pathnameL, what="corrected"))
-      equal <- identical(pathnameLA, target)
+      equal <- identical(pathnameL, target)
       # Be more forgiving on Windows system, i.e. assume a
       # case-insensitive file system
       if (!equal && (.Platform$OS.type == "windows")) {
-        equal <- identical(tolower(pathnameLA), tolower(target))
+        equal <- identical(tolower(pathnameL), tolower(target))
       }
+
+      if (!equal) {
+        pathnameLA <- getAbsolutePath(Sys.readlink2(pathnameL, what="corrected"))
+        equal <- identical(pathnameLA, target)
+        # Be more forgiving on Windows system, i.e. assume a
+        # case-insensitive file system
+        if (!equal && (.Platform$OS.type == "windows")) {
+          equal <- identical(tolower(pathnameLA), tolower(target))
+        }
+      }
+
       if (!equal) {
         warning(sprintf("Existing link (%s; current working directory: %s) was skipped, but it links to different target file than requested: %s != %s", sQuote(link), sQuote(getwd()), sQuote(pathnameLA), sQuote(target)))
       }
